Deferring tasks improvements.

- [X] what if an \@after file is queried solo on the command line?
- [ ] \@after with headers from the current file, not just filenames?
- [X] \@after combined with --ignore on the command line produces warnings,
      it should check we're not deliberately ignoring
